/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.builders;

import java.lang.String;
import org.ovirt.engine.sdk4.internal.containers.CertificateContainer;
import org.ovirt.engine.sdk4.types.Certificate;

public class CertificateBuilder {
    private String comment;
    private String content;
    private String description;
    private String href;
    private String id;
    private String name;
    private String organization;
    private String subject;
    
    public CertificateBuilder comment(String newComment) {
        comment = newComment;
        return this;
    }
    
    
    public CertificateBuilder content(String newContent) {
        content = newContent;
        return this;
    }
    
    
    public CertificateBuilder description(String newDescription) {
        description = newDescription;
        return this;
    }
    
    
    public CertificateBuilder href(String newHref) {
        href = newHref;
        return this;
    }
    
    
    public CertificateBuilder id(String newId) {
        id = newId;
        return this;
    }
    
    
    public CertificateBuilder name(String newName) {
        name = newName;
        return this;
    }
    
    
    public CertificateBuilder organization(String newOrganization) {
        organization = newOrganization;
        return this;
    }
    
    
    public CertificateBuilder subject(String newSubject) {
        subject = newSubject;
        return this;
    }
    
    
    public Certificate build() {
        CertificateContainer container = new CertificateContainer();
        container.comment(comment);
        container.content(content);
        container.description(description);
        container.href(href);
        container.id(id);
        container.name(name);
        container.organization(organization);
        container.subject(subject);
        return container;
    }
}
