/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.HostBuilder;
import org.ovirt.engine.sdk4.types.Host;

/**
 * This service represents list of hosts that have a specific
 * label when accessed through the affinitylabels/hosts
 * subcollection.
 */
public interface AffinityLabelHostsService extends Service {
    /**
     * Add a label to a host.
     */
    public interface AddRequest extends Request<AddRequest, AddResponse> {
        AddRequest host(Host host);
        AddRequest host(HostBuilder host);
    }
    
    /**
     * Add a label to a host.
     */
    public interface AddResponse extends Response {
        Host host();
    }
    
    /**
     * Add a label to a host.
     */
    AddRequest add();
    
    /**
     * List all hosts with the label.
     * 
     * The order of the returned hosts isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
    }
    
    /**
     * List all hosts with the label.
     * 
     * The order of the returned hosts isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<Host> hosts();
    }
    
    /**
     * List all hosts with the label.
     * 
     * The order of the returned hosts isn't guaranteed.
     */
    ListRequest list();
    
    /**
     * A link to the specific label-host assignment to
     * allow label removal.
     */
    AffinityLabelHostService hostService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

