/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.Image;

/**
 * Manages the set of images available in an storage domain or in an OpenStack image provider.
 */
public interface ImagesService extends Service {
    /**
     * Returns the list of images available in the storage domain or provider.
     * 
     * The order of the returned list of images isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Sets the maximum number of images to return. If not specified all the images are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of images to return. If not specified all the images are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of images to return. If not specified all the images are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    /**
     * Returns the list of images available in the storage domain or provider.
     * 
     * The order of the returned list of images isn't guaranteed.
     */
    public interface ListResponse extends Response {
        List<Image> images();
    }
    
    /**
     * Returns the list of images available in the storage domain or provider.
     * 
     * The order of the returned list of images isn't guaranteed.
     */
    ListRequest list();
    
    ImageService imageService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

