/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.GraphicsConsole;

public interface InstanceTypeGraphicsConsoleService extends Service {
    /**
     * Gets graphics console configuration of the instance type.
     */
    public interface GetRequest extends Request<GetRequest, GetResponse> {
    }
    
    /**
     * Gets graphics console configuration of the instance type.
     */
    public interface GetResponse extends Response {
        /**
         * The information about the graphics console of the instance type.
         */
        GraphicsConsole console();
    }
    
    /**
     * Gets graphics console configuration of the instance type.
     */
    GetRequest get();
    
    /**
     * Remove the graphics console from the instance type.
     */
    public interface RemoveRequest extends Request<RemoveRequest, RemoveResponse> {
        /**
         * Indicates if the remove should be performed asynchronously.
         */
        RemoveRequest async(Boolean async);
    }
    
    /**
     * Remove the graphics console from the instance type.
     */
    public interface RemoveResponse extends Response {
    }
    
    /**
     * Remove the graphics console from the instance type.
     */
    RemoveRequest remove();
    
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

